This crate provides the functionality for the Nitro CLI process.
Modules
- common
- The common module (shared between the CLI and enclave process).
- enclave_
proc - The enclave process module.
- enclave_
proc_ comm - The module covering the communication between a CLI instance and enclave processes.
- utils
- The CLI-specific utilities module.
Macros
- create_
app - Macro defining the arguments configuration for a Nitro CLI application.
- new_
nitro_ cli_ failure - Macro used for constructing a NitroCliFailure in a more convenient manner.
Constants
- CID_
TO_ CONSOLE_ PORT_ OFFSET - An offset applied to an enclave’s CID in order to determine its console port.
- VMADDR_
CID_ HYPERVISOR - Hypervisor CID as defined by http://man7.org/linux/man-pages/man7/vsock.7.html.
Functions
- build_
enclaves - Build an enclave image file with the provided arguments.
- build_
from_ docker - Build an enclave image file from a Docker image.
- console_
enclaves - Wrapper over the console connection function.
- describe_
eif - Returns information related to the given EIF
- enclave_
console - Connects to the enclave console and prints it continously.
- get_
all_ enclave_ names - Queries all enclaves for their name
- get_
file_ pcr - For the given file, return the PCR value
- get_
id_ by_ name - Sends the name to all the running enclaves and expects a response with the ID of the one that uniquely matched
- new_
enclave_ name - Creates new enclave name
- sign_
eif - Signs EIF with the given key and certificate. If EIF already has a signature, it will be replaced.
- terminate_
all_ enclaves - Terminates all enclave instances belonging to the current user (or all
instances, if the current user has
rootpermissions).