Module commands_parser

Module commands_parser 

The module which parses command parameters from command-line arguments.

Structs

BuildEnclavesArgs
The arguments used by the build-enclave command.
ConsoleArgs
The arguments used by the console command.
DescribeEnclavesArgs
The arguments used by describe-enclaves command.
EmptyArgs
Empty set of arguments.
ExplainArgs
The arguments used by the explain command.
PcrArgs
The arguments used by pcr command
RunEnclavesArgs
The arguments used by the run-enclave command.
SignEifArgs
The arguments used by sign-eif command
TerminateEnclavesArgs
The arguments used by the terminate-enclave command.

Functions

parse_memory
Parse the requested amount of enclave memory from the command-line arguments. It can be just a number like 123, or it can end in a size indicator like 100M or 10G. If the size indicator is missing, it defaults to M. If the size indicator is not M, G or T, it returns an error.