pub fn parse_memory(args: &ArgMatches) -> NitroCliResult<u64>Expand description
Parse the requested amount of enclave memory from the command-line arguments. It can be just a number like 123, or it can end in a size indicator like 100M or 10G. If the size indicator is missing, it defaults to M. If the size indicator is not M, G or T, it returns an error.
Arguments
args- The command-line arguments.