pub struct BuildEnclavesArgs {
pub docker_uri: String,
pub docker_dir: Option<String>,
pub output: String,
pub signing_certificate: Option<String>,
pub private_key: Option<String>,
pub img_name: Option<String>,
pub img_version: Option<String>,
pub metadata: Option<String>,
}Expand description
The arguments used by the build-enclave command.
Fields
docker_uri: StringThe URI to the Docker image.
docker_dir: Option<String>The directory containing the Docker image.
output: StringThe path where the enclave image file will be written to.
signing_certificate: Option<String>The path to the signing certificate for signed enclaves.
private_key: Option<String>KMS key ARN or path to the private key for signed enclaves.
img_name: Option<String>The name of the enclave image.
img_version: Option<String>The version of the enclave image.
metadata: Option<String>The path to custom metadata JSON file
Implementations
Sourceimpl BuildEnclavesArgs
impl BuildEnclavesArgs
Sourcepub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
pub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
Construct a new BuildEnclavesArgs instance from the given command-line arguments.