pub struct ConsoleArgs {
pub enclave_id: String,
pub disconnect_timeout_sec: Option<u64>,
}Expand description
The arguments used by the console command.
Fields
enclave_id: StringThe ID of the enclave whose console is to be shown.
disconnect_timeout_sec: Option<u64>The time in seconds after the console disconnects from the enclave.
Implementations
Sourceimpl ConsoleArgs
impl ConsoleArgs
Sourcepub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
pub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
Construct a new ConsoleArgs instance from the given command-line arguments.