pub struct SignEifArgs {
pub eif_path: String,
pub signing_certificate: Option<String>,
pub private_key: Option<String>,
}Expand description
The arguments used by sign-eif command
Fields
eif_path: StringPath to the EIF file needed for signing
signing_certificate: Option<String>The path to the signing certificate for signed enclaves.
private_key: Option<String>ARN of the KMS key or path to the local private key for signed enclaves.
Implementations
Sourceimpl SignEifArgs
impl SignEifArgs
Sourcepub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
pub fn new_with(args: &ArgMatches) -> NitroCliResult<Self>
Construct a new SignEifArgs instance from the given command-line arguments.