Module document_errors

Module document_errors 

The module which provides mappings between NitroCliErrors and their corresponding code.

Structs

ERROR_CODES
Structure mapping enum Errors to a specific error code.

Functions

construct_backtrace
Returns a string containing the backtrace recorded during propagating an error message
construct_help_link
Returns a link with more detailed information regarding a specific error.
explain_error
Detailed information based on user-provided error code.
get_detailed_info
Returns detailed error information based on supplied arguments.