pub enum EnclaveProcessCommandType {
Run = 0,
Terminate = 1,
TerminateComplete = 2,
Describe = 3,
GetEnclaveCID = 4,
GetEnclaveFlags = 5,
GetEnclaveName = 6,
GetIDbyName = 7,
ConnectionListenerStop = 8,
NotPermitted = 9,
}Expand description
The type of commands that can be sent to an enclave process.
Variants
Run = 0
Launch (run) an enclave (sent by the CLI).
Terminate = 1
Terminate an enclave (sent by the CLI).
TerminateComplete = 2
Notify that the enclave has terminated (sent by the enclave process to itself).
Describe = 3
Describe an enclave (broadcast by the CLI).
GetEnclaveCID = 4
Request an enclave’s CID (sent by the CLI).
GetEnclaveFlags = 5
Request an enclave’s flags (sent by the CLI).
GetEnclaveName = 6
Request an enclave’s name (sent by the CLI).
GetIDbyName = 7
Request the ID of an enclave only if the name matches (sent by the CLI).
ConnectionListenerStop = 8
Notify the socket connection listener to shut down (sent by the enclave process to itself).
NotPermitted = 9
Do not execute a command due to insufficient privileges (sent by the CLI, modified by the enclave process).