pub enum EnclaveProcessReply {
StdOutMessage(String),
StdErrMessage(String),
Status(i32),
}Expand description
The type of replies that an enclave process can send to a CLI instance.
Variants
StdOutMessage(String)
A message which must be printed to the CLI’s standard output.
StdErrMessage(String)
A messge which must be printed to the CLI’s standard error.
Status(i32)
The status of the operation that the enclave process has performed.