get_socket_path

Function get_socket_path 

pub fn get_socket_path(enclave_id: &str) -> NitroCliResult<PathBuf>
Get the path to the Unix socket owned by an enclave process which also owns the enclave with the given ID.