pub struct EnclaveProcLogWriter { /* private fields */ }Expand description
A log writer which outputs its messages to a custom file. It also allows the updating of its ID, in order to indicate which process is actually logging a message. This implementation will also enable synchronized logging to a centralized file for multiple enclaves.
Implementations
Sourceimpl EnclaveProcLogWriter
impl EnclaveProcLogWriter
Sourcepub fn new() -> NitroCliResult<Self>
pub fn new() -> NitroCliResult<Self>
Create a new log writer.
Sourcepub fn update_logger_id(&self, new_id: &str) -> NitroCliResult<()>
pub fn update_logger_id(&self, new_id: &str) -> NitroCliResult<()>
Update the logger ID (correlated with the process which is doing logging).