pub struct NitroCliFailure {
pub action: String,
pub subactions: Vec<String>,
pub error_code: NitroCliErrorEnum,
pub file: String,
pub line: u32,
pub additional_info: Vec<String>,
}Expand description
Struct that is passed along the backtrace and accumulates error messages.
Fields
action: StringMain action which was attempted and failed.
subactions: Vec<String>(Possibly) more subactions which lead to the root cause of the failure.
error_code: NitroCliErrorEnumComputer-readable error code.
file: StringFile in which the root error occurred.
line: u32Line at which the root error occurred.
additional_info: Vec<String>Additional info regarding the error, passed as individual components (for easier parsing).
Implementations
Sourceimpl NitroCliFailure
impl NitroCliFailure
Sourcepub fn set_action(self, action: String) -> Self
pub fn set_action(self, action: String) -> Self
Sets the main action which failed (i.e. RUN_ENCLAVE).
Sourcepub fn add_subaction(self, subaction: String) -> Self
pub fn add_subaction(self, subaction: String) -> Self
Adds a new layer into the backtrace, corresponding to a failing subaction (i.e. NOT_ENOUGH_MEM).
Sourcepub fn set_error_code(self, error_code: NitroCliErrorEnum) -> Self
pub fn set_error_code(self, error_code: NitroCliErrorEnum) -> Self
Sets the error code.
Sourcepub fn set_file_and_line(self, file: &str, line: u32) -> Self
pub fn set_file_and_line(self, file: &str, line: u32) -> Self
Sets both error file and error line.