pub struct Connection { /* private fields */ }Expand description
An enclave process connection to a CLI instance, an enclave or itself.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn new(epoll_flags: EpollFlags, input_stream: Option<UnixStream>) -> Self
pub fn new(epoll_flags: EpollFlags, input_stream: Option<UnixStream>) -> Self
Create a new connection instance.
Sourcepub fn read_command(&self) -> NitroCliResult<EnclaveProcessCommandType>
pub fn read_command(&self) -> NitroCliResult<EnclaveProcessCommandType>
Read a command and its corresponding credentials.
Sourcepub fn read<T>(&self) -> NitroCliResult<T>where
T: DeserializeOwned,
pub fn read<T>(&self) -> NitroCliResult<T>where
T: DeserializeOwned,
Read an object of the specified type from this connection.
Sourcepub fn write_u64(&self, value: u64) -> NitroCliResult<()>
pub fn write_u64(&self, value: u64) -> NitroCliResult<()>
Write a 64-bit unsigned value on this connection.
Sourcepub fn println(&self, msg: &str) -> NitroCliResult<()>
pub fn println(&self, msg: &str) -> NitroCliResult<()>
Write a message to the standard output of the connection’s other end.
Sourcepub fn eprintln(&self, msg: &str) -> NitroCliResult<()>
pub fn eprintln(&self, msg: &str) -> NitroCliResult<()>
Write a message to the standard error of the connection’s other end.
Sourcepub fn write_status(&self, status: i32) -> NitroCliResult<()>
pub fn write_status(&self, status: i32) -> NitroCliResult<()>
Write an operation’s status to the connection’s other end.
Sourcepub fn get_enclave_event_flags(&self) -> NitroCliResult<Option<EpollFlags>>
pub fn get_enclave_event_flags(&self) -> NitroCliResult<Option<EpollFlags>>
Get the enclave event flags.