pub struct Console { /* private fields */ }Expand description
The structure representing the console of an enclave.
Implementations
Sourceimpl Console
impl Console
Sourcepub fn new(cid: u32, port: u32) -> NitroCliResult<Self>
pub fn new(cid: u32, port: u32) -> NitroCliResult<Self>
Create a new blocking Console connection from a given enclave CID and a vsock port.
Sourcepub fn new_nonblocking(cid: u32, port: u32) -> NitroCliResult<Self>
pub fn new_nonblocking(cid: u32, port: u32) -> NitroCliResult<Self>
Create a new non-blocking Console connection from a given enclave CID and a vsock port.
Sourcepub fn read_to(
&self,
output: &mut dyn Write,
disconnect_timeout_sec: Option<u64>,
) -> NitroCliResult<()>
pub fn read_to( &self, output: &mut dyn Write, disconnect_timeout_sec: Option<u64>, ) -> NitroCliResult<()>
Read a chunk of raw data from the console and output it.
Sourcepub fn read_to_buffer(
&self,
buf: &mut Vec<u8>,
duration: Duration,
) -> NitroCliResult<()>
pub fn read_to_buffer( &self, buf: &mut Vec<u8>, duration: Duration, ) -> NitroCliResult<()>
Read a chunk of raw data to a buffer.