Crate nitro_cli

Crate nitro_cli 

This crate provides the functionality for the Nitro CLI process.

Modules

common
The common module (shared between the CLI and enclave process).
enclave_proc
The enclave process module.
enclave_proc_comm
The module covering the communication between a CLI instance and enclave processes.
utils
The CLI-specific utilities module.

Macros

create_app
Macro defining the arguments configuration for a Nitro CLI application.
new_nitro_cli_failure
Macro used for constructing a NitroCliFailure in a more convenient manner.

Constants

CID_TO_CONSOLE_PORT_OFFSET
An offset applied to an enclave’s CID in order to determine its console port.
VMADDR_CID_HYPERVISOR
Hypervisor CID as defined by http://man7.org/linux/man-pages/man7/vsock.7.html.

Functions

build_enclaves
Build an enclave image file with the provided arguments.
build_from_docker
Build an enclave image file from a Docker image.
console_enclaves
Wrapper over the console connection function.
describe_eif
Returns information related to the given EIF
enclave_console
Connects to the enclave console and prints it continously.
get_all_enclave_names
Queries all enclaves for their name
get_file_pcr
For the given file, return the PCR value
get_id_by_name
Sends the name to all the running enclaves and expects a response with the ID of the one that uniquely matched
new_enclave_name
Creates new enclave name
sign_eif
Signs EIF with the given key and certificate. If EIF already has a signature, it will be replaced.
terminate_all_enclaves
Terminates all enclave instances belonging to the current user (or all instances, if the current user has root permissions).