The module which parses command parameters from command-line arguments.
Structs
- Build
Enclaves Args - The arguments used by the
build-enclavecommand. - Console
Args - The arguments used by the
consolecommand. - Describe
Enclaves Args - The arguments used by
describe-enclavescommand. - Empty
Args - Empty set of arguments.
- Explain
Args - The arguments used by the
explaincommand. - PcrArgs
- The arguments used by
pcrcommand - RunEnclaves
Args - The arguments used by the
run-enclavecommand. - Sign
EifArgs - The arguments used by
sign-eifcommand - Terminate
Enclaves Args - The arguments used by the
terminate-enclavecommand.
Functions
- parse_
memory - Parse the requested amount of enclave memory from the command-line arguments. It can be just a number like 123, or it can end in a size indicator like 100M or 10G. If the size indicator is missing, it defaults to M. If the size indicator is not M, G or T, it returns an error.