The module which provides mappings between NitroCliErrors and their corresponding code.
Structs
- ERROR_
CODES - Structure mapping enum Errors to a specific error code.
Functions
- construct_
backtrace - Returns a string containing the backtrace recorded during propagating an error message
- construct_
help_ link - Returns a link with more detailed information regarding a specific error.
- explain_
error - Detailed information based on user-provided error code.
- get_
detailed_ info - Returns detailed error information based on supplied arguments.